@@ -3,12 +3,15 @@
  */
 
 /*
- * Copyright (c) 1995, 1996, 1997 Joey Hess (joey@kite.ml.org)
+ * Copyright (c) 1995, 1996, 1997 Joey Hess (joey@kitenet.net)
  * All rights reserved. See COPYING for full copyright information (GPL).
  */
 
 /* Delimiter of fields in the rc file */
-#define FIELD_DELIM ":"
+#define FIELD_DELIM ':'
+
+/* Delimeter of flags within feilds in the rd file */
+#define FLAG_DELIM ','
 
 /* Put this before the character in a menu item that is to become the hotkey */
 #define HOTKEY_SEL_CHAR '_'
@@ -18,18 +21,23 @@
 #define SHOW_MENU_KEYWORD "show"
 #define EXEC_KEYWORD "exec"
 #define EXIT_KEYWORD "exit"
-#define COLOR_KEYWORD "color" /* British types may want to change this to colour :-) */
+/* British types may want to change this to colour :-) */
+#define COLOR_KEYWORD "color"
 #define NOP_KEYWORD "nop"
 #define READ_KEYWORD "read"
 #define PREPROC_KEYWORD "preproc"
+#define REMOVE_KEYWORD "remove"
+#define GROUP_KEYWORD "group"
+#define ENDGROUP_KEYWORD "endgroup"
 
 /* The flags that can be used are.. */
-#define NO_CLEAR_FLAG 'n'
+#define NOCLEAR_FLAG 'n'
 #define PAUSE_FLAG 'p'
 #define DISPLAY_FLAG 'd'
 #define EDIT_FLAG 'e'
-#define PUTENV_FLAG 's'
-#define DISPLAY_TRUNCATE_FLAG 't'
+#define SETENV_FLAG 's'
+#define TRUNCATE_FLAG 't'
+#define MAKEMENU_FLAG 'm'
 
 /* The names of the parts of the screen, for color setting, are */
 #define DESKTOP_NAME "desktop"
@@ -40,5 +48,6 @@
 #define SHADOW_NAME "shadow"
 #define MENU_HI_NAME "menuhot"
 #define SELBAR_HI_NAME "selbarhot"
+#define UNSEL_MENU_NAME "unselmenu"
 /* The longest of the strings above is how many characters? */
 #define LONGEST_OBJ_NAME 9
